@@ -5,7 +5,7 @@
 #' See the documentation for those functions for more details.
 #'
 #' @param ... arguments passed to base function,
-#' plus any of the [interactive_parameters()].
+#' plus any of the [interactive_parameters].
 #' @inheritSection interactive_parameters Details for interactive geom functions
 #' @examples
 #' # add interactive bar -------
@@ -25,7 +25,8 @@ GeomInteractiveSmooth <- ggproto(
   default_aes = add_default_interactive_aes(GeomSmooth),
   parameters = interactive_geom_parameters,
   draw_key = interactive_geom_draw_key,
-  draw_group = function(data, panel_params, coord, se = FALSE, flipped_aes = FALSE, .ipar = IPAR_NAMES) {
+  draw_group = function(data, panel_params, coord, lineend = "butt", linejoin = "round",
+                        linemitre = 10, se = FALSE, flipped_aes = FALSE, .ipar = IPAR_NAMES) {
     ribbon <- transform(data, colour = NA)
     path <- transform(data, alpha = NA)
 
@@ -36,7 +37,7 @@ GeomInteractiveSmooth <- ggproto(
     gList(
       if (has_ribbon)
         GeomInteractiveRibbon$draw_group(ribbon, panel_params, coord, flipped_aes = flipped_aes, .ipar = .ipar),
-      GeomInteractiveLine$draw_panel(path, panel_params, coord, .ipar = .ipar)
+      GeomInteractiveLine$draw_panel(path, panel_params, coord, lineend = lineend, linejoin = linejoin, linemitre = linemitre, .ipar = .ipar)
     )
   }
 )
